### Name: clValid
### Title: Validate Cluster Results
### Aliases: clValid
### Keywords: cluster

### ** Examples


data(mouse)

## internal validation
express <- mouse[1:25,c("M1","M2","M3","NC1","NC2","NC3")]
rownames(express) <- mouse$ID[1:25]
intern <- clValid(express, 2:6, clMethods=c("hierarchical","fanny","model"),
                  validation="internal")

## view results
summary(intern)
optimalScores(intern)
plot(intern)

## stability measures
stab <- clValid(express, 2:6, clMethods=c("hierarchical","fanny","model"),
                validation="stability")
optimalScores(stab)
plot(stab)

## biological measures
## first way - functional classes predetermined
fc <- tapply(rownames(express),mouse$FC[1:25], c)
fc <- fc[-match( c("EST","Unknown"), names(fc))]
bio <- clValid(express, 2:6, clMethods=c("hierarchical","fanny","model"),
               validation="biological", annotation=fc)
optimalScores(bio)
plot(bio)

## second way - using Bioconductor
if(require("Biobase") && require("annotate") && require("GO") && require("moe430a")) {
  bio2 <- clValid(express, 2:6, clMethods=c("hierarchical","fanny","model"),
                  validation="biological",annotation="moe430a",GOcategory="all")
  optimalScores(bio2)
  plot(bio2)
}




